#
# spec file for package simde
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           simde
Version:        0.8.2+git20240621.c903416
Release:        bp160.1.6
Summary:        Fallback implementation for SIMD intrinsics
License:        MIT
URL:            https://github.com/simd-everywhere/%{name}
Source:         %{name}-%{version}.tar.gz
BuildRequires:  meson
BuildRequires:  c++_compiler
# simde >= 0.8.0, build errors out if this is set related to simde.pc
#BuildArch:      noarch

%description
Portable implementations of SIMD intrinsics.

%package devel
Summary:        Fallback implementation for SIMD intrinsics

%description devel
The SIMDe header-only library provides fast, portable implementations of SIMD
intrinsics on hardware which do not natively support them, such as calling
SSE functions on ARM. There is no performance penalty if the hardware supports
the native implementation (e.g. SSE/AVX runs at full speed on x86, NEON on
ARM, etc.).

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

%files devel
%{_includedir}/%{name}
%{_libdir}/pkgconfig/simde.pc
%license COPYING
%doc README.md

%changelog
* Mon Jun 24 2024 scott.bradnick@suse.com
- Update to version 0.8.2+git20240621.c903416:
  * arm/neon riscv64: additional RVV implementations - part 2. (#1189)
  * arm/neon riscv64: additional RVV implementations - part1 (#1188)
  * Use _Float16 in C++ on aarch64 with GCC 13+
  * Don't use _Float16 on non-SSE2 x86
  * Don't use _Float16 on s390x
  * x86: Apply half tabular method in _mm_crc32 family
  * arm: improve performance in vqadd and vmvn in risc-v
  * neon: avoid warnings when "__ARM_NEON_FP" is not defined.
  * Add @zengdage as a contributor
  * Add @howjmay as a contributor
  * Add @Torinde as a contributor
  * Add @eric900115 as a contributor
  * Add @AymenQ as a contributor
  * add git mail map
  * start next development cycle: v0.8.3
* Tue Apr 30 2024 scott.bradnick@suse.com
- Setting "BuildArch: noarch" causes build to fail, commented out
- Update to version 0.8.2+git20240430.71fd833:
  * prepare to release 0.8.0
  * arm neon: Fully remove the problematic FCVTZS/FCVTMS/FCVTPS/FCVTNS family intrinsics
  * arm: improve performance in vabd_xxx for risc-v
  * arm: improve performance in vhadd_xxx for risc-v
  * README: two more related projects
  * arm: Add neon2rvv support in vand series intrinsics
  * arm: fix some neon2rvv intrinsic function error
  * arm: enable more intrinsic function for armv7
  * wasm x86 impl: some were incorrectly marked SSE instead of SSE2
  * arm x86 implementations: allow _m128 access from SSE
  * tests x86, adjust import order so that MSVC pragma are processed early
  * svml: SSE is good enough for native m128i and m128d types & functions
  * sse2 MSVC `_mm_pause` implementaiton for x86
  * x86 test msvc: really disable warning 4799,4730
  * typo fixes from codespell
  * README.md - move CLMUL to partial, list more of the CI.yml architectures
  * Update README.md - link to VPCLMULQDQ; mention MSA (#1157)
  * Update README.md (#1156)
  * Packit: Drop i386 (i686) support. (#1155)
  * gh-actions: build for AMD Buildozer version 2
  * x86 xop: fix some native functions
  * emscripten; use `__builtin_roundeven{f,}` from version 3.1.43 onwards
  * arm 32 bits: native def fixes; workarounds for gcc
  * Add gcc arm 32bit armv8-a test in CI
  * CI: don't run twice on dependabot branches
  * gh-actions codecov: use token
  * build(deps): bump codecov/codecov-action from 3 to 4
  * update list of fully implemented instruction sets (#1152)
  * apple clang arm64: ignore SHA2
  * semaphore: stop testing on GCC 5 & 6, clang 3.9 & 4 due to forced upgrade to Ubuntu 20.04
  * gh-actions macos: report log if there is a configuration failure.
  * arm platform: cleanup feature detection.
  * arm neon sm3: check constant range
  * arm neon: disable some FCVTZS/FCVTMS/FCVTPS/FCVTNS family intrinsics
  * cirrus: upgrade to clang-17
  * gh-actions: test Mac arm64
  * arm neon clang: skip vrnd native before clang v18
  * clang: detect versions 18 & 19
  * build(deps): bump actions/checkout from 3 to 4 (#1149)
* Thu Mar 14 2024 scott.bradnick@suse.com
- Update to version 0.8.0+git20240314.b4e805a:
  * Initial Support for the RISC-V Vector Extension in ARM NEON (#1130)
  * start next development cycle: v0.8.1
* Thu Mar  7 2024 scott.bradnick@suse.com
- Update to version 0.8.0+git20240307.589c7d5:
  * Add @thomas-schlichter as a contributor
  * Add @Proudsalsa as a contributor
  * Add @Coeur as a contributor
* Mon Feb 26 2024 Jan Engelhardt <jengelh@inai.de>
- Trim unnecessary main package
* Mon Feb 26 2024 scott.bradnick@suse.com
- Update to version 0.8.0-rc1+git20240222.c200c16:
  * arm/neon abs: negating INT_MIN is undefined behavior
  * docs: explain how to target a single test
  * build(deps): bump actions/checkout from 3 to 4
  * gh-actions: add new repo for clang-16
  * gh-actions emscripten: use older release
  * docker: ignore common build paths
  * build(deps): bump github/codeql-action from 2 to 3 (#1138)
  * build(deps): bump actions/setup-python from 4 to 5 (#1137)
  * build(deps): bump actions/setup-dotnet from 3 to 4 (#1135)
  * build(deps): bump ad-m/github-push-action from 0.6.0 to 0.8.0 (#1134)
* Mon Feb 26 2024 Scott Bradnick <scott.bradnick@suse.com>
- Initial version from upstream.
